Crate engineioxide_core

Crate engineioxide_core 

Engineioxide-core

Common types and utilities for engineioxide and socketioxide-core.

  • Sid a unique identifier for a socket connection.
  • Str a wrapper around Bytes that ensures UTF-8 encoding.

Modules

payload
Payload encoder and decoder for polling transport.

Structs

OpenPacket
An OpenPacket is used to initiate a connection
Sid
A 128 bit session id type representing a base64 16 char string
Str
A custom Bytes wrapper to efficiently store string packets
UnknownTransportError
Cannot determine the transport type to connect to the client/server.

Enums

Packet
A Packet type to use when receiving and sending data from the client
PacketParseError
An error that occurs when parsing a packet.
ProtocolVersion
The engine.io protocol version
TransportType
The type of transport used to connect to the client/server.

Type Aliases

PacketBuf
Buffered packets to send to the client. It is used to ensure atomicity when sending multiple packets to the client.