pub struct Payload {
pub data: Bytes,
pub has_binary: bool,
pub peeked: Option<PacketBuf>,
}Expand description
A payload to transmit to the client through http polling
Fields
data: BytesThe data of the payload.
has_binary: boolWhether the payload contains binary data.
peeked: Option<PacketBuf>A peeked packet buffer that could not be sent due to the max payload size.
Implementations