Engineioxide-core
Common types and utilities for engineioxide and socketioxide-core.
Sida unique identifier for a socket connection.Stra wrapper aroundBytesthat ensures UTF-8 encoding.
Modules
- payload
- Payload encoder and decoder for polling transport.
Structs
- Open
Packet - An OpenPacket is used to initiate a connection
- Sid
- A 128 bit session id type representing a base64 16 char string
- Str
- A custom
Byteswrapper to efficiently store string packets - Unknown
Transport Error - Cannot determine the transport type to connect to the client/server.
Enums
- Packet
- A Packet type to use when receiving and sending data from the client
- Packet
Parse Error - An error that occurs when parsing a packet.
- Protocol
Version - The engine.io protocol version
- Transport
Type - The type of
transportused to connect to the client/server.
Type Aliases
- Packet
Buf - Buffered packets to send to the client. It is used to ensure atomicity when sending multiple packets to the client.